This directory contains example files needed to run a fully automated prescreen / rescreen experiment on the imaging machine, coordinated from python.  
See the [pdf file](https://github.com/Luxendo/Acquifer-Python-API/blob/master/examples/prescreen_rescreen/Prescreen_Rescreen_IM.pdf) for a schematic illustration of the workflow.  

## Files

- 2x-script.imsf  
Pre-screen script for overview imaging.  
This file is generated via the Imaging Machine control software, based on the settings defined by the user in the GUI.  
It is actually written in C#, but for this use-case this does not really matter, we mostly treat the script as a black box containing the parameters needed for the acquisition.  

- 4x-script.imsf  
Similar than the previous script, with settings for the rescreen imaging (here higher spatial-resolution imaging)  

- 4X-SCRIPT-CENTERED.IMSF  
This script was generated by the python script.  
It is identical to the 4x-script, with the exception that the coordinates were updated based on the detected image positions.  
This is the script actually run last, for the rescreen.  

- Prescreen_Rescreen.py  
Main python script orchestrating the prescreen/rescreen workflow, and in charge of localizing objects in images (here using template matching).    
See the top of this python script file for requirements (python packages...).  
Run this script once the requirements are fullfilled to run the prescreen/rescreen.
